@@ -202,8 +202,9 @@ class Text(Accessible):
                 """
                 func = self.get_dbus_method("GetAttributes", dbus_interface=ATSPI_TEXT)
                 [attrs, startOffset, endOffset] = func(Int32(offset))
-                dict = [key + ':' + attrs[key] for key in attrs]
-                return [dict, startOffset, endOffset]
+                arr = [key + ':' + value for key, value in attrs.items()]
+		str = ';'.join (arr)
+                return [str, startOffset, endOffset]
 
         def getBoundedRanges(self, x, y, width, height, coordType, xClipType, yClipType):
                 #TODO Return a list of range structures
@@ -531,11 +532,11 @@ class Text(Accessible):
                 @return True if the selection corresponding to selectionNum is
                 successfully modified, False otherwise.
                 """
-                func = self.get_dbus_method("setSelection", dbus_interface=ATSPI_TEXT)
+                func = self.get_dbus_method("SetSelection", dbus_interface=ATSPI_TEXT)
                 return func(selectionNum, startOffset, endOffset)
 
         def get_caretOffset(self):
-                return Int32(self._pgetter(self.dbus_interface, "CaretOffset"))
+                return Int32(self._pgetter(ATSPI_TEXT, "CaretOffset"))
         _caretOffsetDoc = \
                 """
                 The current offset of the text caret in the Text object. This
@@ -548,7 +549,7 @@ class Text(Accessible):
         caretOffset = property(fget=get_caretOffset, doc=_caretOffsetDoc)
 
         def get_characterCount(self):
-                return Int32(self._pgetter(self.dbus_interface, "CharacterCount"))
+                return Int32(self._pgetter(ATSPI_TEXT, "CharacterCount"))
         _characterCountDoc = \
                 """
                 The total current number of characters in the Text object, including
